@@ -177,7 +177,7 @@ class Pixel:
         self.fit = fit
         self.fit_form = fit_form
         self.method = method
-        self.filter_amp = filter_amplitude
+        self.filter_amplitude = filter_amplitude
         
         # Default Cantilever parameters, plugging in some reasonable defaults
         self.AMPINVOLS = 122e-9 
@@ -398,19 +398,18 @@ class Pixel:
         
         return 
     
-    def filter_amplitude(self):
+    def amplitude_filter(self):
         '''
-        filters the drive signal out of the amplitude response
+        Filters the drive signal out of the amplitude response
         '''
-        
         AMP = np.fft.fftshift(np.fft.fft(self.amplitude)) 
         
         DRIVE = self.drive_freq/(self.sampling_rate/self.n_points) # drive location in frequency space
         center = int(len(AMP)/2)
         
         # crude boxcar
-        AMP[:center-int(DRIVE/2)] = 0
-        AMP[center+int(DRIVE/2):] = 0
+        AMP[:center-int(DRIVE/2)+1] = 0
+        AMP[center+int(DRIVE/2)-1:] = 0
         
         self.amplitude = np.abs( np.fft.ifft(np.fft.ifftshift(AMP)) )
         
@@ -474,19 +473,20 @@ class Pixel:
         x = np.arange(ridx)
         y = cut
 
-        func = spi.UnivariateSpline(x, y, k=4, ext=3)
-
+        _spline_sz = 2 * self.sampling_rate / self.drive_freq
+        func = spi.UnivariateSpline(x, y, k=4, ext=3, s=_spline_sz)
+        
         # Find the minimum of the spline using TNC method.
         res = spo.minimize(func, cut.argmin(),
                            method='TNC', bounds=((0, ridx),))
         idx = res.x[0]
 
+        self.cut = cut
+        self.best_fit = func(np.arange(ridx))
+
         # Do index to time conversion and find shift.
         self.tfp = idx / self.sampling_rate
         self.shift = func(0) - func(idx)
-        
-        self.cut = cut
-        self.best_fit = 0 * cut
 
         return
 
@@ -943,8 +943,9 @@ class Pixel:
             # Calculate the amplitude and phase from the analytic signal
             self.calculate_amplitude()
             
-            if self.filter_amp:
-                self.filter_amplitude()
+            if self.filter_amplitude:
+                
+                self.amplitude_filter()
             
             self.calculate_phase()
 
